let audio = null;
let loadTimeout = null;
let currentOperation = Promise.resolve();

function clearLoadTimeout() {
    if (loadTimeout) {
        clearTimeout(loadTimeout);
        loadTimeout = null;
    }
}

async function stopCurrentAudio() {
    if (!audio) return;
    
    clearLoadTimeout();
    
    return new Promise(resolve => {
        const onPaused = () => {
            audio.removeEventListener('pause', onPaused);
            audio = null;
            resolve();
        };
        
        audio.addEventListener('pause', onPaused);
        audio.pause();
    });
}

async function playAudio(request) {
    // עוצרים את התחנה הנוכחית
    await stopCurrentAudio();

    // מנסים להפעיל את התחנה החדשה
    return new Promise((resolve, reject) => {
        console.log(`[${new Date().toISOString()}] Starting to load stream:`, request.url);
        audio = new Audio(request.url);
        audio.volume = request.volume;

        loadTimeout = setTimeout(() => {
            console.log(`[${new Date().toISOString()}] Stream load timeout`);
            stopCurrentAudio();
            reject(new Error('התחנה לא נטענה בזמן סביר'));
        }, 15000);

        audio.addEventListener('loadstart', () => {
            console.log(`[${new Date().toISOString()}] Stream loading started`);
            chrome.runtime.sendMessage({
                target: 'popup',
                action: 'loading',
                stationId: request.stationId
            });
        });

        audio.addEventListener('playing', () => {
            console.log(`[${new Date().toISOString()}] Stream started playing`);
            clearLoadTimeout();
            resolve();
        }, { once: true });

        audio.addEventListener('error', () => {
            const errors = {
                1: 'התחנה לא זמינה',
                2: 'בעיית חיבור לאינטרנט',
                3: 'התחנה לא נתמכת',
                4: 'התחנה לא נמצאה'
            };
            const errorMessage = errors[audio.error.code] || 'שגיאה לא ידועה';
            console.error(`[${new Date().toISOString()}] Stream error:`, errorMessage);
            clearLoadTimeout();
            reject(new Error(errorMessage));
        }, { once: true });

        audio.play().catch(error => {
            console.error(`[${new Date().toISOString()}] Play error:`, error);
            clearLoadTimeout();
            reject(error);
        });
    });
}

chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.target !== 'offscreen') return;

    try {
        switch (request.action) {
            case 'play':
                // מוסיף את הפעולה לתור
                currentOperation = currentOperation
                    .then(() => playAudio(request))
                    .then(() => {
                        chrome.runtime.sendMessage({
                            target: 'popup',
                            action: 'playing',
                            stationId: request.stationId
                        });
                    })
                    .catch(error => {
                        chrome.runtime.sendMessage({
                            target: 'popup',
                            action: 'error',
                            stationId: request.stationId,
                            error: error.message
                        });
                    });
                
                sendResponse({ status: 'loading' });
                break;

            case 'stop':
                currentOperation = currentOperation
                    .then(() => stopCurrentAudio());
                sendResponse({ status: 'stopped' });
                break;

            case 'setVolume':
                if (audio) {
                    audio.volume = request.volume;
                }
                sendResponse({ status: 'volume updated' });
                break;
        }
    } catch (error) {
        console.error(`[${new Date().toISOString()}] Script error:`, error);
        clearLoadTimeout();
        sendResponse({ error: error.message });
    }

    return true;
});
