let currentButton = null;
let lastPlayedStation = null;
let isPlaying = false;

const stations = {
    kolChaiMusic: {
        url: 'https://live.kcm.fm/livemusic',
        button: document.getElementById('kolChaiMusic'),
        name: 'קול חי מיוזיק'
    },
    kolPlay: {
        url: 'https://cdn.cybercdn.live/Kol_Barama/Music/icecast.audio',
        button: document.getElementById('kolPlay'),
        name: 'קול פליי'
    },
    jewishMusic: {
        url: 'https://stream.jewishmusicstream.com:8000/stream',
        button: document.getElementById('jewishMusic'),
        name: 'Jewish Music Stream'
    },
    tokerFM: {
        url: 'https://broadcast.adpronet.com/radio/6060/radio.mp3',
        button: document.getElementById('tokerFM'),
        name: 'טוקר FM'
    },
    kolSimcha: {
        url: 'https://broadcast.adpronet.com/radio/8000/radio.mp3',
        button: document.getElementById('kolSimcha'),
        name: 'קול שמחה'
    }
};

async function initializePlayer() {
    const volumeControl = document.getElementById('volumeControl');
    const stopButton = document.getElementById('stopButton');
    
    // Load saved volume and last station
    const { volume, currentStation, isPlaying: savedIsPlaying } = 
        await chrome.storage.local.get(['volume', 'currentStation', 'isPlaying']);
    
    if (volume !== undefined) {
        volumeControl.value = volume;
    }
    
    // איפוס כל הכפתורים
    Object.values(stations).forEach(station => {
        station.button.classList.remove('playing', 'loading', 'error');
    });

    // בדיקת מצב הנגינה הנוכחי
    try {
        if (currentStation && stations[currentStation]) {
            lastPlayedStation = currentStation;
            if (savedIsPlaying) {
                currentButton = stations[currentStation].button;
                isPlaying = true;
                updatePlayerState(true, currentStation);
            } else {
                updatePlayerState(false, currentStation);
            }
        }
    } catch (error) {
        console.error('שגיאה בקבלת מצב הנגינה:', error);
    }

    for (const stationId in stations) {
        const station = stations[stationId];
        station.button.addEventListener('click', () => playStation(stationId));
    }

    volumeControl.addEventListener('input', async (e) => {
        const newVolume = e.target.value;
        await chrome.storage.local.set({ volume: newVolume });
        chrome.runtime.sendMessage({ 
            action: 'setVolume',
            volume: newVolume,
            target: 'offscreen'
        });
    });

    stopButton.addEventListener('click', togglePlayback);

    // האזנה להודעות מה-offscreen
    chrome.runtime.onMessage.addListener((message) => {
        if (message.target === 'popup') {
            const station = stations[message.stationId];
            if (!station) return;

            switch (message.action) {
                case 'loading':
                    console.log('Stream is loading:', message.stationId);
                    station.button.classList.remove('playing', 'error');
                    station.button.classList.add('loading');
                    station.button.setAttribute('data-status', 'טוען...');
                    break;
                    
                case 'playing':
                    console.log('Stream started playing:', message.stationId);
                    station.button.classList.remove('loading', 'error');
                    station.button.classList.add('playing');
                    station.button.removeAttribute('data-status');
                    break;

                case 'error':
                    console.error('Stream error:', message.error);
                    station.button.classList.remove('loading', 'playing');
                    station.button.classList.add('error');
                    station.button.setAttribute('data-status', message.error);
                    // אחרי 5 שניות, מנקה את מצב השגיאה
                    setTimeout(() => {
                        station.button.classList.remove('error');
                        station.button.removeAttribute('data-status');
                    }, 5000);
                    break;
            }
        }
    });
}

function updatePlayerState(playing, stationId = null) {
    isPlaying = playing;
    
    // עדכון כפתורי התחנות
    Object.keys(stations).forEach(id => {
        stations[id].button.classList.remove('playing', 'loading', 'error');
    });

    const currentStationElement = document.getElementById('currentStation');
    
    if (stationId && stations[stationId]) {
        if (playing) {
            currentButton = stations[stationId].button;
            currentButton.classList.add('playing');
            currentStationElement.textContent = `מתנגן עכשיו: ${stations[stationId].name}`;
            currentStationElement.style.color = '#f44336';
        } else {
            currentStationElement.textContent = `תחנה אחרונה: ${stations[stationId].name}`;
            currentStationElement.style.color = '#4CAF50';
        }
    }
    
    document.getElementById('stopButton').textContent = playing ? 'עצור' : 'נגן';
}

async function playStation(stationId) {
    const station = stations[stationId];
    console.log('Starting to play station:', stationId);
    
    // אם זו אותה תחנה שמנגנת כרגע, נעצור אותה
    if (currentButton === station.button && isPlaying) {
        await stopPlayback();
        return;
    }

    // אם מנגנת תחנה אחרת, קודם נעצור אותה
    if (isPlaying) {
        await stopPlayback();
    }

    const { volume } = await chrome.storage.local.get('volume');
    const currentVolume = volume !== undefined ? volume : document.getElementById('volumeControl').value;

    try {
        // מיד מוסיף מצב טעינה
        station.button.classList.add('loading');
        station.button.setAttribute('data-status', 'טוען...');
        
        chrome.runtime.sendMessage({ 
            action: 'play',
            url: station.url,
            volume: currentVolume,
            stationId: stationId,
            target: 'offscreen'
        });

        currentButton = station.button;
        lastPlayedStation = stationId;
        updatePlayerState(true, stationId);
    } catch (error) {
        console.error('שגיאה בהפעלת התחנה:', error);
        station.button.classList.remove('loading');
        station.button.setAttribute('data-status', error.message);
        station.button.classList.add('error');
        updatePlayerState(false, stationId);
        
        // אחרי 5 שניות, מנקה את מצב השגיאה
        setTimeout(() => {
            station.button.classList.remove('error');
            station.button.removeAttribute('data-status');
        }, 5000);
    }
}

async function stopPlayback() {
    chrome.runtime.sendMessage({ 
        action: 'stop',
        target: 'offscreen'
    });
    updatePlayerState(false, lastPlayedStation);
    currentButton = null;
}

async function togglePlayback() {
    if (isPlaying) {
        await stopPlayback();
    } else if (lastPlayedStation) {
        await playStation(lastPlayedStation);
    }
}

document.addEventListener('DOMContentLoaded', initializePlayer);
